Clone

Trait Clone 

1.6.0 (const: unstable) ยท Source
pub trait Clone: Sized {
    // Required method
    fn clone(&self) -> Self;

    // Provided method
    fn clone_from(&mut self, source: &Self)
       where Self: { ... }
}
A common trait that allows explicit creation of a duplicate value.

Calling clone always produces a new value. However, for types that are references to other data (such as smart pointers or references), the new value may still point to the same underlying data, rather than duplicating it. See Clone::clone for more details.

This distinction is especially important when using #[derive(Clone)] on structs containing smart pointers like Arc<Mutex<T>> - the cloned struct will share mutable state with the original.

Differs from Copy in that Copy is implicit and an inexpensive bit-wise copy, while Clone is always explicit and may or may not be expensive. Copy has no methods, so you cannot change its behavior, but when implementing Clone, the clone method you provide may run arbitrary code.

Since Clone is a supertrait of Copy, any type that implements Copy must also implement Clone.

Derivable

This trait can be used with #[derive] if all fields are Clone. The derived implementation of Clone calls clone on each field.

For a generic struct, #[derive] implements Clone conditionally by adding bound Clone on generic parameters.

// `derive` implements Clone for Reading<T> when T is Clone.
#[derive(Clone)]
struct Reading<T> {
    frequency: T,
}

How can I implement Clone?

Types that are Copy should have a trivial implementation of Clone. More formally: if T: Copy, x: T, and y: &T, then let x = y.clone(); is equivalent to let x = *y;. Manual implementations should be careful to uphold this invariant; however, unsafe code must not rely on it to ensure memory safety.

An example is a generic struct holding a function pointer. In this case, the implementation of Clone cannot be derived, but can be implemented as:

struct Generate<T>(fn() -> T);

impl<T> Copy for Generate<T> {}

impl<T> Clone for Generate<T> {
    fn clone(&self) -> Self {
        *self
    }
}

If we derive:

#[derive(Copy, Clone)]
struct Generate<T>(fn() -> T);

the auto-derived implementations will have unnecessary T: Copy and T: Clone bounds:


// Automatically derived
impl<T: Copy> Copy for Generate<T> { }

// Automatically derived
impl<T: Clone> Clone for Generate<T> {
    fn clone(&self) -> Generate<T> {
        Generate(Clone::clone(&self.0))
    }
}

The bounds are unnecessary because clearly the function itself should be copy- and cloneable even if its return type is not:

โ“˜
#[derive(Copy, Clone)]
struct Generate<T>(fn() -> T);

struct NotCloneable;

fn generate_not_cloneable() -> NotCloneable {
    NotCloneable
}

Generate(generate_not_cloneable).clone(); // error: trait bounds were not satisfied
// Note: With the manual implementations the above line will compile.

Clone and PartialEq/Eq

Clone is intended for the duplication of objects. Consequently, when implementing both Clone and PartialEq, the following property is expected to hold:

x == x -> x.clone() == x

In other words, if an object compares equal to itself, its clone must also compare equal to the original.

For types that also implement Eq โ€“ for which x == x always holds โ€“ this implies that x.clone() == x must always be true. Standard library collections such as HashMap, HashSet, BTreeMap, BTreeSet and BinaryHeap rely on their keys respecting this property for correct behavior. Furthermore, these collections require that cloning a key preserves the outcome of the Hash and Ord methods. Thankfully, this follows automatically from x.clone() == x if Hash and Ord are correctly implemented according to their own requirements.

When deriving both Clone and PartialEq using #[derive(Clone, PartialEq)] or when additionally deriving Eq using #[derive(Clone, PartialEq, Eq)], then this property is automatically upheld โ€“ provided that it is satisfied by the underlying types.

Violating this property is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on this property being satisfied.

Additional implementors

In addition to the implementors listed below, the following types also implement Clone:

  • Function item types (i.e., the distinct types defined for each function)
  • Function pointer types (e.g., fn() -> i32)
  • Closure types, if they capture no value from the environment or if all such captured values implement Clone themselves. Note that variables captured by shared reference always implement Clone (even if the referent doesnโ€™t), while variables captured by mutable reference never implement Clone.

Required Methods

1.0.0 (const: unstable) ยท Source

fn clone(&self) -> Self

Returns a duplicate of the value.

Note that what โ€œduplicateโ€ means varies by type:

  • For most types, this creates a deep, independent copy
  • For reference types like &T, this creates another reference to the same value
  • For smart pointers like Arc or Rc, this increments the reference count but still points to the same underlying data
Examples
let hello = "Hello"; // &str implements Clone

assert_eq!("Hello", hello.clone());

Example with a reference-counted type:

use std::sync::{Arc, Mutex};

let data = Arc::new(Mutex::new(vec![1, 2, 3]));
let data_clone = data.clone(); // Creates another Arc pointing to the same Mutex

{
    let mut lock = data.lock().unwrap();
    lock.push(4);
}

// Changes are visible through the clone because they share the same underlying data
assert_eq!(*data_clone.lock().unwrap(), vec![1, 2, 3, 4]);

Provided Methods

1.0.0 (const: unstable) ยท Source

fn clone_from(&mut self, source: &Self)
where Self:,

Performs copy-assignment from source.

a.clone_from(&b) is equivalent to a = b.clone() in functionality, but can be overridden to reuse the resources of a to avoid unnecessary allocations.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Clone for !

1.0.0 ยท Source

impl Clone for AddrParseError

Source

impl Clone for core::mem::Alignment

1.28.0 ยท Source

impl Clone for core::fmt::Alignment

Source

impl Clone for AllocError

Source

impl Clone for AsciiChar

Source

impl Clone for Assume

Source

impl Clone for CharCase

1.34.0 ยท Source

impl Clone for CharTryFromError

1.27.0 ยท Source

impl Clone for CpuidResult

Available on x86 or x86-64 only.
Source

impl Clone for DebugAsHex

1.9.0 ยท Source

impl Clone for DecodeUtf16Error

1.3.0 ยท Source

impl Clone for Duration

1.0.0 ยท Source

impl Clone for core::io::Empty

1.0.0 ยท Source

impl Clone for Error

1.0.0 ยท Source

impl Clone for ErrorKind

1.20.0 ยท Source

impl Clone for core::char::EscapeDebug

1.0.0 ยท Source

impl Clone for core::ascii::EscapeDefault

1.0.0 ยท Source

impl Clone for core::char::EscapeDefault

1.0.0 ยท Source

impl Clone for core::char::EscapeUnicode

Source

impl Clone for FieldId

Source

impl Clone for FormattingOptions

1.0.0 ยท Source

impl Clone for FpCategory

1.69.0 ยท Source

impl Clone for FromBytesUntilNulError

1.64.0 ยท Source

impl Clone for FromBytesWithNulError

1.86.0 ยท Source

impl Clone for GetDisjointMutError

Source

impl Clone for core::arch::hexagon::v64::HvxVector

Available on Hexagon only.
Source

impl Clone for core::arch::hexagon::v128::HvxVector

Available on Hexagon only.
Source

impl Clone for core::arch::hexagon::v64::HvxVectorPair

Available on Hexagon only.
Source

impl Clone for core::arch::hexagon::v128::HvxVectorPair

Available on Hexagon only.
Source

impl Clone for core::arch::hexagon::v64::HvxVectorPred

Available on Hexagon only.
Source

impl Clone for core::arch::hexagon::v128::HvxVectorPred

Available on Hexagon only.
1.34.0 (const: unstable) ยท Source

impl Clone for Infallible

1.55.0 ยท Source

impl Clone for IntErrorKind

1.7.0 ยท Source

impl Clone for IpAddr

1.0.0 (const: unstable) ยท Source

impl Clone for Ipv4Addr

1.0.0 (const: unstable) ยท Source

impl Clone for Ipv6Addr

Source

impl Clone for Ipv6MulticastScope

1.28.0 ยท Source

impl Clone for Layout

1.50.0 ยท Source

impl Clone for LayoutError

Source

impl Clone for LocalWaker

Source

impl Clone for Locality

1.0.0 (const: unstable) ยท Source

impl Clone for core::cmp::Ordering

1.0.0 ยท Source

impl Clone for core::sync::atomic::Ordering

1.0.0 ยท Source

impl Clone for ParseBoolError

1.20.0 ยท Source

impl Clone for ParseCharError

1.0.0 ยท Source

impl Clone for ParseFloatError

1.0.0 ยท Source

impl Clone for ParseIntError

1.33.0 ยท Source

impl Clone for PhantomPinned

1.0.0 (const: unstable) ยท Source

impl Clone for RangeFull

1.36.0 ยท Source

impl Clone for RawWakerVTable

Source

impl Clone for SearchStep

Source

impl Clone for Sign

1.0.0 ยท Source

impl Clone for Sink

1.0.0 ยท Source

impl Clone for SipHasher

1.0.0 ยท Source

impl Clone for SocketAddr

1.0.0 ยท Source

impl Clone for SocketAddrV4

1.0.0 ยท Source

impl Clone for SocketAddrV6

Source

impl Clone for ToCasefold

1.0.0 ยท Source

impl Clone for ToLowercase

Source

impl Clone for ToTitlecase

1.0.0 ยท Source

impl Clone for ToUppercase

1.59.0 ยท Source

impl Clone for TryFromCharError

1.66.0 ยท Source

impl Clone for TryFromFloatSecsError

1.34.0 ยท Source

impl Clone for TryFromIntError

1.34.0 ยท Source

impl Clone for TryFromSliceError

1.0.0 (const: unstable) ยท Source

impl Clone for TypeId

1.0.0 ยท Source

impl Clone for Utf8Error

1.36.0 ยท Source

impl Clone for Waker

1.27.0 ยท Source

impl Clone for __m128

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Clone for __m256

Available on x86 or x86-64 only.
1.72.0 ยท Source

impl Clone for __m512

Available on x86 or x86-64 only.
1.89.0 ยท Source

impl Clone for __m128bh

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Clone for __m128d

Available on x86 or x86-64 only.
1.94.0 ยท Source

impl Clone for __m128h

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Clone for __m128i

Available on x86 or x86-64 only.
1.89.0 ยท Source

impl Clone for __m256bh

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Clone for __m256d

Available on x86 or x86-64 only.
1.94.0 ยท Source

impl Clone for __m256h

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Clone for __m256i

Available on x86 or x86-64 only.
1.89.0 ยท Source

impl Clone for __m512bh

Available on x86 or x86-64 only.
1.72.0 ยท Source

impl Clone for __m512d

Available on x86 or x86-64 only.
1.94.0 ยท Source

impl Clone for __m512h

Available on x86 or x86-64 only.
1.72.0 ยท Source

impl Clone for __m512i

Available on x86 or x86-64 only.
Source

impl Clone for __tile1024i

Available on x86-64 only.
Source

impl Clone for bf16

Available on x86 or x86-64 only.
1.0.0 (const: unstable) ยท Source

impl Clone for bool

1.0.0 (const: unstable) ยท Source

impl Clone for char

1.0.0 (const: unstable) ยท Source

impl Clone for f16

1.0.0 (const: unstable) ยท Source

impl Clone for f32

1.0.0 (const: unstable) ยท Source

impl Clone for f64

Source

impl Clone for f16x2

Available on NVidia GPU only.
1.0.0 (const: unstable) ยท Source

impl Clone for f128

1.94.0 ยท Source

impl Clone for float16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Clone for float16x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Clone for float16x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Clone for float16x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Clone for float16x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Clone for float16x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Clone for float16x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Clone for float16x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for float32x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for float32x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for float32x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for float32x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for float32x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for float32x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for float32x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for float32x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for float64x1_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Clone for float64x1x2_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Clone for float64x1x3_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Clone for float64x1x4_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Clone for float64x2_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Clone for float64x2x2_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Clone for float64x2x3_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Clone for float64x2x4_t

Available on AArch64 or ARM64EC only.
1.0.0 (const: unstable) ยท Source

impl Clone for i8

1.0.0 (const: unstable) ยท Source

impl Clone for i16

1.0.0 (const: unstable) ยท Source

impl Clone for i32

1.0.0 (const: unstable) ยท Source

impl Clone for i64

1.0.0 (const: unstable) ยท Source

impl Clone for i128

1.59.0 ยท Source

impl Clone for int8x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int8x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int8x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int8x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int8x16_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int8x16x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int8x16x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int8x16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int16x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int16x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int16x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int16x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int16x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int16x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int16x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int32x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int32x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int32x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int32x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int32x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int32x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int32x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int32x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int64x1_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int64x1x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int64x1x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int64x1x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int64x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int64x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int64x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for int64x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.0.0 (const: unstable) ยท Source

impl Clone for isize

Source

impl Clone for m128

Available on LoongArch64 only.
Source

impl Clone for m256

Available on LoongArch64 only.
Source

impl Clone for m128d

Available on LoongArch64 only.
Source

impl Clone for m128i

Available on LoongArch64 only.
Source

impl Clone for m256d

Available on LoongArch64 only.
Source

impl Clone for m256i

Available on LoongArch64 only.
1.59.0 ยท Source

impl Clone for poly8x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly8x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly8x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly8x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly8x16_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly8x16x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly8x16x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly8x16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly16x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly16x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly16x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly16x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly16x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly16x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly16x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly64x1_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly64x1x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly64x1x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly64x1x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly64x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly64x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly64x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for poly64x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
Source

impl Clone for svbool_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svfloat32_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svfloat32x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svfloat32x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svfloat32x4_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svfloat64_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svfloat64x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svfloat64x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svfloat64x4_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint8_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint8x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint8x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint8x4_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint16_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint16x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint16x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint16x4_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint32_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint32x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint32x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint32x4_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint64_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint64x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint64x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svint64x4_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svpattern

Available on AArch64 or ARM64EC only.
Source

impl Clone for svprfop

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint8_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint8x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint8x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint8x4_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint16_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint16x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint16x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint16x4_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint32_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint32x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint32x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint32x4_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint64_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint64x2_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint64x3_t

Available on AArch64 or ARM64EC only.
Source

impl Clone for svuint64x4_t

Available on AArch64 or ARM64EC only.
1.0.0 (const: unstable) ยท Source

impl Clone for u8

1.0.0 (const: unstable) ยท Source

impl Clone for u16

1.0.0 (const: unstable) ยท Source

impl Clone for u32

1.0.0 (const: unstable) ยท Source

impl Clone for u64

1.0.0 (const: unstable) ยท Source

impl Clone for u128

1.59.0 ยท Source

impl Clone for uint8x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint8x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint8x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint8x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint8x16_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint8x16x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint8x16x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint8x16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint16x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint16x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint16x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint16x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint16x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint16x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint16x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint32x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint32x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint32x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint32x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint32x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint32x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint32x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint32x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint64x1_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint64x1x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint64x1x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint64x1x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint64x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint64x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint64x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Clone for uint64x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.0.0 (const: unstable) ยท Source

impl Clone for usize

1.54.0 ยท Source

impl Clone for v128

Available on target_family=wasm only.
Source

impl Clone for core::arch::powerpc::vector_bool_char

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_bool_char

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_bool_int

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_bool_int

Available on s390x only.
Source

impl Clone for vector_bool_long

Available on PowerPC or PowerPC64 only.
Source

impl Clone for vector_bool_long_long

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_bool_short

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_bool_short

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_double

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_double

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_float

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_float

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_signed_char

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_signed_char

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_signed_int

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_signed_int

Available on s390x only.
Source

impl Clone for vector_signed_long

Available on PowerPC or PowerPC64 only.
Source

impl Clone for vector_signed_long_long

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_signed_short

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_signed_short

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_unsigned_char

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_unsigned_char

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_unsigned_int

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_unsigned_int

Available on s390x only.
Source

impl Clone for vector_unsigned_long

Available on PowerPC or PowerPC64 only.
Source

impl Clone for vector_unsigned_long_long

Available on s390x only.
Source

impl Clone for core::arch::powerpc::vector_unsigned_short

Available on PowerPC or PowerPC64 only.
Source

impl Clone for core::arch::s390x::vector_unsigned_short

Available on s390x only.
Source

impl<'a, 'b, const N: usize> Clone for CharArrayRefSearcher<'a, 'b, N>

Source

impl<'a, 'b> Clone for CharSliceSearcher<'a, 'b>

Source

impl<'a, 'b> Clone for StrSearcher<'a, 'b>

Source

impl<'a, F> Clone for CharPredicateSearcher<'a, F>
where F: FnMut(char) -> bool + Clone,

1.51.0 ยท Source

impl<'a, P: Pattern<Searcher<'a>: Clone>> Clone for core::str::SplitInclusive<'a, P>

1.5.0 ยท Source

impl<'a, P> Clone for MatchIndices<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.2.0 ยท Source

impl<'a, P> Clone for Matches<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.5.0 ยท Source

impl<'a, P> Clone for RMatchIndices<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.2.0 ยท Source

impl<'a, P> Clone for RMatches<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.0.0 ยท Source

impl<'a, P> Clone for core::str::RSplit<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.0.0 ยท Source

impl<'a, P> Clone for RSplitN<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.0.0 ยท Source

impl<'a, P> Clone for RSplitTerminator<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.0.0 ยท Source

impl<'a, P> Clone for core::str::Split<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.0.0 ยท Source

impl<'a, P> Clone for SplitN<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.0.0 ยท Source

impl<'a, P> Clone for SplitTerminator<'a, P>
where P: Pattern<Searcher<'a>: Clone>,

1.89.0 ยท Source

impl<'a, T: 'a, P: Clone> Clone for ChunkBy<'a, T, P>

1.31.0 ยท Source

impl<'a, T> Clone for RChunksExact<'a, T>

Source

impl<'a, const N: usize> Clone for CharArraySearcher<'a, N>

1.0.0 ยท Source

impl<'a> Clone for Arguments<'a>

Source

impl<'a> Clone for core::ffi::c_str::Bytes<'a>

1.0.0 ยท Source

impl<'a> Clone for core::str::Bytes<'a>

1.0.0 ยท Source

impl<'a> Clone for CharIndices<'a>

Source

impl<'a> Clone for CharSearcher<'a>

1.0.0 ยท Source

impl<'a> Clone for Chars<'a>

1.8.0 ยท Source

impl<'a> Clone for EncodeUtf16<'a>

1.60.0 ยท Source

impl<'a> Clone for EscapeAscii<'a>

1.34.0 ยท Source

impl<'a> Clone for core::str::EscapeDebug<'a>

1.34.0 ยท Source

impl<'a> Clone for core::str::EscapeDefault<'a>

1.34.0 ยท Source

impl<'a> Clone for core::str::EscapeUnicode<'a>

1.36.0 ยท Source

impl<'a> Clone for IoSlice<'a>

1.0.0 ยท Source

impl<'a> Clone for Lines<'a>

1.0.0 ยท Source

impl<'a> Clone for LinesAny<'a>

1.10.0 ยท Source

impl<'a> Clone for Location<'a>

Source

impl<'a> Clone for PhantomContravariantLifetime<'a>

Source

impl<'a> Clone for PhantomCovariantLifetime<'a>

Source

impl<'a> Clone for PhantomInvariantLifetime<'a>

Source

impl<'a> Clone for Source<'a>

1.34.0 ยท Source

impl<'a> Clone for SplitAsciiWhitespace<'a>

1.1.0 ยท Source

impl<'a> Clone for SplitWhitespace<'a>

1.79.0 ยท Source

impl<'a> Clone for Utf8Chunk<'a>

1.79.0 ยท Source

impl<'a> Clone for Utf8Chunks<'a>

Source

impl<'a> Clone for Utf8Pattern<'a>

Source

impl<'f> Clone for VaList<'f>

1.0.0 ยท Source

impl<A: Clone, B: Clone> Clone for Chain<A, B>

1.0.0 ยท Source

impl<A: Clone, B: Clone> Clone for Zip<A, B>

1.0.0 ยท Source

impl<A: Clone> Clone for core::option::IntoIter<A>

Source

impl<A: Clone> Clone for OptionFlatten<A>

1.96.0 ยท Source

impl<A: Clone> Clone for RangeFromIter<A>

1.95.0 ยท Source

impl<A: Clone> Clone for RangeInclusiveIter<A>

1.96.0 ยท Source

impl<A: Clone> Clone for RangeIter<A>

1.0.0 ยท Source

impl<A: Clone> Clone for Repeat<A>

1.82.0 ยท Source

impl<A: Clone> Clone for RepeatN<A>

1.0.0 ยท Source

impl<A> Clone for core::option::Iter<'_, A>

1.55.0 (const: unstable) ยท Source

impl<B: Clone, C: Clone> Clone for ControlFlow<B, C>

Source

impl<Dyn: PointeeSized> Clone for DynMetadata<Dyn>

1.34.0 ยท Source

impl<F: Clone> Clone for FromFn<F>

1.43.0 ยท Source

impl<F: Clone> Clone for OnceWith<F>

1.28.0 ยท Source

impl<F: Clone> Clone for RepeatWith<F>

Source

impl<G: Clone> Clone for FromCoroutine<G>

1.7.0 ยท Source

impl<H> Clone for BuildHasherDefault<H>

Source

impl<I, F, const N: usize> Clone for MapWindows<I, F, N>
where I: Iterator + Clone, F: Clone, I::Item: Clone,

Source

impl<I, G> Clone for IntersperseWith<I, G>
where I: Iterator + Clone, I::Item: Clone, G: Clone,

1.29.0 ยท Source

impl<I, U> Clone for Flatten<I>
where I: Clone + Iterator<Item: IntoIterator<IntoIter = U, Item = U::Item>>, U: Clone + Iterator,

Source

impl<I: Clone + Iterator, const N: usize> Clone for ArrayChunks<I, N>
where I::Item: Clone,

Source

impl<I: Clone + Iterator> Clone for Intersperse<I>
where I::Item: Clone + Clone,

1.0.0 ยท Source

impl<I: Clone + Iterator> Clone for Peekable<I>
where I::Item: Clone,

1.0.0 ยท Source

impl<I: Clone, F: Clone> Clone for FilterMap<I, F>

1.0.0 ยท Source

impl<I: Clone, F: Clone> Clone for Inspect<I, F>

1.0.0 ยท Source

impl<I: Clone, F: Clone> Clone for Map<I, F>

1.0.0 ยท Source

impl<I: Clone, P: Clone> Clone for Filter<I, P>

1.57.0 ยท Source

impl<I: Clone, P: Clone> Clone for MapWhile<I, P>

1.0.0 ยท Source

impl<I: Clone, P: Clone> Clone for SkipWhile<I, P>

1.0.0 ยท Source

impl<I: Clone, P: Clone> Clone for TakeWhile<I, P>

1.0.0 ยท Source

impl<I: Clone, St: Clone, F: Clone> Clone for Scan<I, St, F>

1.0.0 ยท Source

impl<I: Clone, U, F: Clone> Clone for FlatMap<I, U, F>
where U: Clone + IntoIterator<IntoIter: Clone>,

1.1.0 ยท Source

impl<I: Clone> Clone for Cloned<I>

1.36.0 ยท Source

impl<I: Clone> Clone for Copied<I>

1.0.0 ยท Source

impl<I: Clone> Clone for Cycle<I>

1.0.0 ยท Source

impl<I: Clone> Clone for Enumerate<I>

Source

impl<I: Clone> Clone for FromIter<I>

1.0.0 ยท Source

impl<I: Clone> Clone for Fuse<I>

1.0.0 ยท Source

impl<I: Clone> Clone for Skip<I>

1.28.0 ยท Source

impl<I: Clone> Clone for StepBy<I>

1.0.0 ยท Source

impl<I: Clone> Clone for Take<I>

1.9.0 ยท Source

impl<I> Clone for DecodeUtf16<I>
where I: Iterator<Item = u16> + Clone,

1.0.0 (const: unstable) ยท Source

impl<Idx: Clone> Clone for core::ops::Range<Idx>

1.96.0 (const: unstable) ยท Source

impl<Idx: Clone> Clone for core::range::Range<Idx>

1.0.0 (const: unstable) ยท Source

impl<Idx: Clone> Clone for core::ops::RangeFrom<Idx>

1.96.0 (const: unstable) ยท Source

impl<Idx: Clone> Clone for core::range::RangeFrom<Idx>

1.26.0 ยท Source

impl<Idx: Clone> Clone for core::ops::RangeInclusive<Idx>

1.95.0 ยท Source

impl<Idx: Clone> Clone for core::range::RangeInclusive<Idx>

1.0.0 (const: unstable) ยท Source

impl<Idx: Clone> Clone for RangeTo<Idx>

1.26.0 ยท Source

impl<Idx: Clone> Clone for core::ops::RangeToInclusive<Idx>

1.96.0 ยท Source

impl<Idx: Clone> Clone for core::range::RangeToInclusive<Idx>

Source

impl<P: Clone + ?Sized> Clone for MaybeDangling<P>

1.33.0 ยท Source

impl<Ptr: Clone> Clone for Pin<Ptr>

1.0.0 ยท Source

impl<T, E> Clone for Result<T, E>
where T: Clone, E: Clone,

1.27.0 ยท Source

impl<T, P> Clone for core::slice::RSplit<'_, T, P>
where P: Clone + FnMut(&T) -> bool,

1.0.0 ยท Source

impl<T, P> Clone for core::slice::Split<'_, T, P>
where P: Clone + FnMut(&T) -> bool,

1.51.0 ยท Source

impl<T, P> Clone for core::slice::SplitInclusive<'_, T, P>
where P: Clone + FnMut(&T) -> bool,

1.94.0 ยท Source

impl<T, const N: usize> Clone for ArrayWindows<'_, T, N>

Source

impl<T, const N: usize> Clone for Mask<T, N>
where T: MaskElement,

Source

impl<T, const N: usize> Clone for Simd<T, N>
where T: SimdElement,

Source

impl<T: ?Sized, const VARIANT: u32, const FIELD: u32> Clone for FieldRepresentingType<T, VARIANT, FIELD>

1.20.0 ยท Source

impl<T: Clone + ?Sized> Clone for ManuallyDrop<T>

1.34.0 ยท Source

impl<T: Clone, F: Clone> Clone for Successors<T, F>

1.51.0 ยท Source

impl<T: Clone, const N: usize> Clone for core::array::IntoIter<T, N>

1.58.0 ยท Source

impl<T: Clone, const N: usize> Clone for [T; N]

1.17.0 (const: unstable) ยท Source

impl<T: Clone> Clone for Bound<T>

1.0.0 ยท Source

impl<T: Clone> Clone for core::result::IntoIter<T>

1.2.0 ยท Source

impl<T: Clone> Clone for Once<T>

1.70.0 ยท Source

impl<T: Clone> Clone for OnceCell<T>

1.36.0 ยท Source

impl<T: Clone> Clone for Poll<T>

1.48.0 ยท Source

impl<T: Clone> Clone for Ready<T>

1.0.0 ยท Source

impl<T: Clone> Clone for RefCell<T>

1.0.0 ยท Source

impl<T: Clone> Clone for Rev<T>

1.19.0 ยท Source

impl<T: Clone> Clone for Reverse<T>

1.74.0 ยท Source

impl<T: Clone> Clone for Saturating<T>

1.0.0 ยท Source

impl<T: Clone> Clone for Wrapping<T>

1.0.0 ยท Source

impl<T: Copy> Clone for Cell<T>

1.36.0 ยท Source

impl<T: Copy> Clone for MaybeUninit<T>

1.0.0 ยท Source

impl<T: PointeeSized> !Clone for &mut T

Shared references can be cloned, but mutable references cannot!

1.0.0 (const: unstable) ยท Source

impl<T: PointeeSized> Clone for &T

Shared references can be cloned, but mutable references cannot!

1.0.0 (const: unstable) ยท Source

impl<T: PointeeSized> Clone for *const T

1.0.0 (const: unstable) ยท Source

impl<T: PointeeSized> Clone for *mut T

1.25.0 ยท Source

impl<T: PointeeSized> Clone for NonNull<T>

1.0.0 ยท Source

impl<T: PointeeSized> Clone for PhantomData<T>

1.0.0 ยท Source

impl<T> Clone for Chunks<'_, T>

1.31.0 ยท Source

impl<T> Clone for ChunksExact<'_, T>

1.0.0 ยท Source

impl<T> Clone for Cursor<T>
where T: Clone,

1.21.0 ยท Source

impl<T> Clone for Discriminant<T>

1.2.0 ยท Source

impl<T> Clone for core::iter::Empty<T>

1.0.0 ยท Source

impl<T> Clone for core::result::Iter<'_, T>

1.0.0 ยท Source

impl<T> Clone for core::slice::Iter<'_, T>

1.28.0 (const: unstable) ยท Source

impl<T> Clone for NonZero<T>

1.0.0 (const: unstable) ยท Source

impl<T> Clone for Option<T>
where T: Clone,

1.48.0 ยท Source

impl<T> Clone for Pending<T>

Source

impl<T> Clone for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Clone for PhantomCovariant<T>
where T: ?Sized,

Source

impl<T> Clone for PhantomInvariant<T>
where T: ?Sized,

1.31.0 ยท Source

impl<T> Clone for RChunks<'_, T>

Source

impl<T> Clone for SyncView<T>
where T: Sync + Clone,

1.0.0 ยท Source

impl<T> Clone for Windows<'_, T>

Source

impl<Y: Clone, R: Clone> Clone for CoroutineState<Y, R>